summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/spl-book.cc
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/spl-book.cc')
-rw-r--r--crawl-ref/source/spl-book.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/crawl-ref/source/spl-book.cc b/crawl-ref/source/spl-book.cc
index 839070e53a..d1d0d6f140 100644
--- a/crawl-ref/source/spl-book.cc
+++ b/crawl-ref/source/spl-book.cc
@@ -975,7 +975,7 @@ static int which_spellbook( void )
avail_levels, (avail_levels > 1) ? "s" : "" );
book = prompt_invent_item("Memorise from which spellbook?", MT_INVLIST,
- OBJ_BOOKS );
+ OSEL_MEMORISE );
if (book == PROMPT_ABORT)
{
canned_msg( MSG_OK );
@@ -998,7 +998,7 @@ static int which_spellbook( void )
return (book);
} // end which_spellbook()
// Returns false if the player cannot read/memorize from the book,
// and true otherwise. -- bwr
bool player_can_read_spellbook( const item_def &book )
{
@@ -998,7 +998,7 @@ static int which_spellbook( void )
return (book);
} // end which_spellbook()
-// Returns false if the player cannot read/memorize from the book,
+// Returns false if the player cannot read/memorise from the book,
// and true otherwise. -- bwr
bool player_can_read_spellbook( const item_def &book )